#[non_exhaustive]pub enum ErrorValue {
Path(String),
Sheet(String),
Row {
row: u32,
subrow: u16,
sheet: Option<String>,
},
File(Vec<u8>),
Other(String),
}Expand description
A value associated with an error that occured.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Path(String)
A path to a file.
Sheet(String)
Available on crate feature
excel only.An Excel sheet.
Row
Available on crate feature
exd only.An Excel row.
File(Vec<u8>)
Available on crate feature
sqpack only.A SqPack file.
Other(String)
A value not represented by other variants.
ErrorValues of the Other type should only be matched on with a wildcard
(_) pattern. Values represented by Other may be promoted to a new variant
in future versions.